/* 
 * Copyright (c) 2011, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

/*
 *  ======== lpm_driver.h ========
 *
 */


/**
 *  @file       lpm_driver.h
 *
 *  @brief      This header defines the functions for turning the
 *              external power supply on and off.
 *
 *  @addtogroup   ti_bios_power_LPM     Shared Definitions
 */


/**
 *  @brief      Function typedef of the functions which control the
 *              external power supply.
 */
typedef void (*LPM_ExtPwrFxn)(void *arg);


/**
 *  @brief      Register an external power off function.
 *
 *  @param[in]  device          Linux device name.
 *  @param[in]  fxn             A function address which will turn off the
 *                              external power supply to the DSP Power
 *                              Domain.
 *  @param[in]  arg             An argument passed to the callback function.
 *
 *  @retval     0               The function was successfully registered.
 *  @retval     -1              The given device name was not found.
 */
extern int lpm_regExtOffFxn(char *device, LPM_ExtPwrFxn fxn, void *arg);


/**
 *  @brief      Register an external power on function.
 *
 *  @param[in]  device          Linux device name.
 *  @param[in]  fxn             A function address which will turn off the
 *                              external power supply to the DSP Power
 *                              Domain.
 *  @param[in]  arg             An argument passed to the callback function.
 *
 *  @retval     0               The function was successfully registered.
 *  @retval     -1              The given device name was not found.
 */
extern int lpm_regExtOnFxn(char *device, LPM_ExtPwrFxn fxn, void *arg);
/*
 *  @(#) ti.bios.power; 1, 1, 1,1; 12-9-2011 14:13:01; /db/atree/library/trees/power/power-g11x/src/ xlibrary

 */

